{% extends "django_kerberos/base.html" %}

{% block content %}
An error occurred during initialization of the GSSAPI context, verify that a properly initialized keytab is accessible
  {% if details %}
    <pre>
      {{ details }}
    </pre>
  {% endif %}
{% endblock %}
